@@ -28,61 +28,78 @@
 #  include "config.h"
 #endif
 
+/* This needs to be before glib.h, since it might be used in inline
+ * functions */
+extern const char             g_log_domain_gstreamer[];
+
 #include <glib.h>
 
 #include <stdlib.h>
 #include <string.h>
 
+G_BEGIN_DECLS
+
 gboolean __gst_in_valgrind (void);
 
+/* Initialize GStreamer private quark storage */
+void _priv_gst_quarks_initialize (void);
+
 /*** debugging categories *****************************************************/
 
 #ifndef GST_DISABLE_GST_DEBUG
 
+#ifndef WIN32
+#define IMPORT_SYMBOL
+#else
+#ifndef LIBGSTREAMER_EXPORTS
+#define IMPORT_SYMBOL __declspec(dllimport)
+#else
+#define IMPORT_SYMBOL 
+#endif
+#endif
+
 #include <gst/gstinfo.h>
 
-extern GstDebugCategory *GST_CAT_GST_INIT;
-extern GstDebugCategory *GST_CAT_COTHREADS;
-extern GstDebugCategory *GST_CAT_COTHREAD_SWITCH;
-extern GstDebugCategory *GST_CAT_AUTOPLUG;
-extern GstDebugCategory *GST_CAT_AUTOPLUG_ATTEMPT;
-extern GstDebugCategory *GST_CAT_PARENTAGE;
-extern GstDebugCategory *GST_CAT_STATES;
-extern GstDebugCategory *GST_CAT_PLANNING;
-extern GstDebugCategory *GST_CAT_SCHEDULING;
-extern GstDebugCategory *GST_CAT_BUFFER;
-extern GstDebugCategory *GST_CAT_CAPS;
-extern GstDebugCategory *GST_CAT_CLOCK;
-extern GstDebugCategory *GST_CAT_ELEMENT_PADS;
-extern GstDebugCategory *GST_CAT_PADS;
-extern GstDebugCategory *GST_CAT_PIPELINE;
-extern GstDebugCategory *GST_CAT_PLUGIN_LOADING;
-extern GstDebugCategory *GST_CAT_PLUGIN_INFO;
-extern GstDebugCategory *GST_CAT_PROPERTIES;
-extern GstDebugCategory *GST_CAT_THREAD;
-extern GstDebugCategory *GST_CAT_XML;
-extern GstDebugCategory *GST_CAT_NEGOTIATION;
-extern GstDebugCategory *GST_CAT_REFCOUNTING;
-extern GstDebugCategory *GST_CAT_ERROR_SYSTEM;
-extern GstDebugCategory *GST_CAT_EVENT;
-extern GstDebugCategory *GST_CAT_PARAMS;
-extern GstDebugCategory *GST_CAT_CALL_TRACE;
-extern GstDebugCategory *GST_CAT_SIGNAL;
-extern GstDebugCategory *GST_CAT_PROBE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_GST_INIT;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_AUTOPLUG;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_AUTOPLUG_ATTEMPT;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PARENTAGE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_STATES;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_SCHEDULING;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_BUFFER;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_BUS;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_CAPS;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_CLOCK;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_ELEMENT_PADS;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PADS;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PIPELINE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PLUGIN_LOADING;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PLUGIN_INFO;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PROPERTIES;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_XML;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_NEGOTIATION;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_REFCOUNTING;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_ERROR_SYSTEM;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_EVENT;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_MESSAGE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PARAMS;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_CALL_TRACE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_SIGNAL;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_PROBE;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_REGISTRY;
+extern IMPORT_SYMBOL GstDebugCategory *GST_CAT_QOS;
 
 #else
 
 #define GST_CAT_GST_INIT         NULL
-#define GST_CAT_COTHREADS        NULL
-#define GST_CAT_COTHREAD_SWITCH  NULL
 #define GST_CAT_AUTOPLUG         NULL
 #define GST_CAT_AUTOPLUG_ATTEMPT NULL
 #define GST_CAT_PARENTAGE        NULL
 #define GST_CAT_STATES           NULL
-#define GST_CAT_PLANNING         NULL
 #define GST_CAT_SCHEDULING       NULL
 #define GST_CAT_DATAFLOW         NULL
 #define GST_CAT_BUFFER           NULL
+#define GST_CAT_BUS              NULL
 #define GST_CAT_CAPS             NULL
 #define GST_CAT_CLOCK            NULL
 #define GST_CAT_ELEMENT_PADS     NULL
@@ -91,17 +108,20 @@ extern GstDebugCategory *GST_CAT_PROBE;
 #define GST_CAT_PLUGIN_LOADING   NULL
 #define GST_CAT_PLUGIN_INFO      NULL
 #define GST_CAT_PROPERTIES       NULL
-#define GST_CAT_THREAD           NULL
 #define GST_CAT_XML              NULL
 #define GST_CAT_NEGOTIATION      NULL
 #define GST_CAT_REFCOUNTING      NULL
 #define GST_CAT_ERROR_SYSTEM     NULL
 #define GST_CAT_EVENT            NULL
+#define GST_CAT_MESSAGE          NULL
 #define GST_CAT_PARAMS           NULL
 #define GST_CAT_CALL_TRACE       NULL
 #define GST_CAT_SIGNAL           NULL
 #define GST_CAT_PROBE            NULL
+#define GST_CAT_REGISTRY         NULL
+#define GST_CAT_QOS              NULL
 
 #endif
 
+G_END_DECLS
 #endif /* __GST_PRIVATE_H__ */
